[Python-checkins] cpython (3.5): Closes #28059: Fixes test_platform to set PYTHONPATH for .pyd files

steve.dower python-checkins at python.org
Sat Sep 10 15:25:23 EDT 2016


https://hg.python.org/cpython/rev/94563ec74e1d
changeset:   103580:94563ec74e1d
branch:      3.5
parent:      103578:9eb0f7762999
user:        Steve Dower <steve.dower at microsoft.com>
date:        Sat Sep 10 12:19:42 2016 -0700
summary:
  Closes #28059: Fixes test_platform to set PYTHONPATH for .pyd files

files:
  Lib/test/test_platform.py |  11 +++++++++--
  1 files changed, 9 insertions(+), 2 deletions(-)


diff --git a/Lib/test/test_platform.py b/Lib/test/test_platform.py
--- a/Lib/test/test_platform.py
+++ b/Lib/test/test_platform.py
@@ -15,11 +15,18 @@
 
     @support.skip_unless_symlink
     def test_architecture_via_symlink(self): # issue3762
         # On Windows, the EXE needs to know where pythonXY.dll is at so we have
         # to add the directory to the path.
         if sys.platform == "win32":
+            def restore_environ(old_env):
+                os.environ.clear()
+                os.environ.update(old_env)
+
+            self.addCleanup(restore_environ, dict(os.environ))
+
             os.environ["Path"] = "{};{}".format(
                 os.path.dirname(sys.executable), os.environ["Path"])
+            os.environ["PYTHONPATH"] = os.path.dirname(sys.executable)
 
         def get(python):
             cmd = [python, '-c',
@@ -15,11 +15,18 @@
     @support.skip_unless_symlink
     def test_architecture_via_symlink(self): # issue3762
-        # On Windows, the EXE needs to know where pythonXY.dll is at so we have
-        # to add the directory to the path.
+        # On Windows, the EXE needs to know where pythonXY.dll and *.pyd is at
+        # so we add the directory to the path and PYTHONPATH.
         if sys.platform == "win32":

-- 
Repository URL: https://hg.python.org/cpython


More information about the Python-checkins mailing list